Module notifier

Module notifier 

Long-polling notifier for PostgreSQL provider.

The notifier thread listens for PostgreSQL NOTIFY events and manages timer heaps to wake dispatchers at the right time, reducing idle database polling.

Structs

LongPollConfig
Configuration for long-polling behavior.
Notifier
The notifier thread that manages LISTEN/NOTIFY and timer heaps.

Enums

NotifyAction
Action determined by parsing a NOTIFY payload.

Functions

parse_notify_action
Parse a NOTIFY payload and determine what action to take.
timers_from_refresh
Calculate timers to add from refresh result.