pub enum NotifyAction {
WakeNow,
AddTimer {
fire_at: Instant,
},
Ignore,
}Expand description
Action determined by parsing a NOTIFY payload.
Variants
WakeNow
Work is immediately visible, wake dispatchers now.
AddTimer
Work will be visible in the future, add timer.
Ignore
Work is too far in the future, ignore (refresh will catch it).